pub struct ExportBaoOptions {
pub hash: Hash,
pub ranges: ChunkRanges,
}Expand description
Export the given ranges in bao format, with the iroh block size.
The returned stream should be verified by the store.
Fields
hash: Hashranges: ChunkRangesTrait Implementations
Sourceimpl Debug for ExportBaoRequest
impl Debug for ExportBaoRequest
Sourceimpl<'de> Deserialize<'de> for ExportBaoRequest
impl<'de> Deserialize<'de> for ExportBaoRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more