pub struct ExportOptions {
pub hash: Hash,
pub mode: ExportMode,
pub target: PathBuf,
}Expand description
Export a file to a target path.
For an incomplete file, the size might be truncated and gaps will be filled with zeros. If possible, a store implementation should try to write as a sparse file.
Fields
hash: Hashmode: ExportModetarget: PathBufTrait Implementations
Sourceimpl Debug for ExportPathRequest
impl Debug for ExportPathRequest
Sourceimpl<'de> Deserialize<'de> for ExportPathRequest
impl<'de> Deserialize<'de> for ExportPathRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more