pub struct ExportProgress { /* private fields */ }Expand description
A progress handle for an export operation.
Internally this is a stream of ExportProgress items. Working with this
stream directly can be inconvenient, so this struct provides some convenience
methods to work with the result.
To get the underlying stream, use the ExportProgress::stream method.
It also implements IntoFuture, so you can await it to get the size of the
exported blob.
Implementations
Sourceimpl ExportProgress
impl ExportProgress
pub async fn stream(self) -> impl Stream<Item = ExportProgressItem>
pub async fn finish(self) -> RequestResult<u64>