pub struct ExportRangesProgress { /* private fields */ }Expand description
A progress handle for a bao export operation.
Internally, this is a stream of EncodedItems. Using this stream directly
is often inconvenient, so there are a number of higher level methods to
process the stream.
You can get access to the underlying stream using the ExportBaoProgress::stream method.
Implementations
Sourceimpl ExportRangesProgress
impl ExportRangesProgress
Sourcepub fn stream(self) -> impl Stream<Item = ExportRangesItem>
pub fn stream(self) -> impl Stream<Item = ExportRangesItem>
A raw stream of [ExportRangesItem]s.
Ranges will be rounded up to chunk boundaries. So if you request a range of 0..100, you will get the entire first chunk, 0..1024.
It is up to the caller to clip the ranges to the requested ranges.
Sourcepub async fn concatenate(self) -> RequestResult<Vec<u8>>
pub async fn concatenate(self) -> RequestResult<Vec<u8>>
Concatenate all the data into a single Bytes.