pub struct ImportBaoOptions {
pub hash: Hash,
pub size: NonZeroU64,
}Expand description
Import bao encoded data for the given hash with the iroh block size.
The result is just a single item, indicating if a write error occurred.
To observe the incoming data more granularly, use the Observe command
concurrently.
Fields
hash: Hashsize: NonZeroU64Trait Implementations
Sourceimpl Debug for ImportBaoRequest
impl Debug for ImportBaoRequest
Sourceimpl<'de> Deserialize<'de> for ImportBaoRequest
impl<'de> Deserialize<'de> for ImportBaoRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more