pub struct Downloader { /* private fields */ }Implementations
Sourceimpl Downloader
impl Downloader
pub fn new(store: &Store, endpoint: &Endpoint) -> Self
pub fn new_with_opts( store: &Store, endpoint: &Endpoint, pool_options: Options, ) -> Self
pub fn download( &self, request: impl SupportedRequest, providers: impl ContentDiscovery, ) -> DownloadProgress
pub fn download_with_opts(&self, options: DownloadOptions) -> DownloadProgress
Sourcepub async fn wait_idle(&self) -> Result<()>
pub async fn wait_idle(&self) -> Result<()>
Wait until the downloader has no in-flight download tasks.
This is mostly useful for tests, where you want to confirm that all previously-issued downloads have settled (whether they completed successfully or errored out). Note that the downloader is not guaranteed to become idle if it is being interacted with concurrently; in that case this might wait forever. Also note that once you get the callback, the downloader is not guaranteed to still be idle — all this tells you is that there was a point in time, between the call and the response, where it was idle.