pub enum ConnectedNext<R: RecvStream = RecvStream> {
StartRoot(AtStartRoot<R>),
StartChild(AtStartChild<R>),
Closing(AtClosing<R>),
}Expand description
Possible next states after the handshake has been sent
Variants
StartRoot(AtStartRoot<R>)
First response is either a collection or a single blob
StartChild(AtStartChild<R>)
First response is a child
Closing(AtClosing<R>)
Request is empty