pub struct AtConnected<R: RecvStream = RecvStream, W: SendStream = SendStream> { /* private fields */ }Expand description
State of the get response machine after the handshake has been sent
Implementations
Sourceimpl<R: RecvStream, W: SendStream> AtConnected<R, W>
impl<R: RecvStream, W: SendStream> AtConnected<R, W>
pub fn new( start: Instant, reader: R, writer: W, request: GetRequest, counters: RequestCounters, ) -> Self
Sourcepub async fn next(self) -> Result<ConnectedNext<R>, ConnectedNextError>
pub async fn next(self) -> Result<ConnectedNext<R>, ConnectedNextError>
Send the request and move to the next state
The next state will be either StartRoot or StartChild depending on whether
the request requests part of the collection or not.
If the request is empty, this can also move directly to Finished.