pub struct AtStartChild<R: RecvStream = RecvStream> { /* private fields */ }Expand description
State of the get response when we start reading a child
Implementations
Sourceimpl<R: RecvStream> AtStartChild<R>
impl<R: RecvStream> AtStartChild<R>
Sourcepub fn offset(&self) -> u64
pub fn offset(&self) -> u64
The offset of the child we are currently reading
This must be used to determine the hash needed to call next. If this is larger than the number of children in the collection, you can call finish to stop reading the response.
Sourcepub fn ranges(&self) -> &ChunkRanges
pub fn ranges(&self) -> &ChunkRanges
The ranges we have requested for the child
Sourcepub fn next(self, hash: Hash) -> AtBlobHeader<R>
pub fn next(self, hash: Hash) -> AtBlobHeader<R>
Go into the next state, reading the header
This requires passing in the hash of the child for validation