pub struct GetRequestBuilder { /* private fields */ }Implementations
Sourceimpl GetRequestBuilder
impl GetRequestBuilder
Sourcepub fn offset(self, offset: u64, ranges: impl Into<ChunkRanges>) -> Self
pub fn offset(self, offset: u64, ranges: impl Into<ChunkRanges>) -> Self
Add a range to the request.
Sourcepub fn child(self, child: u64, ranges: impl Into<ChunkRanges>) -> Self
pub fn child(self, child: u64, ranges: impl Into<ChunkRanges>) -> Self
Add a range to the request.
Sourcepub fn root(self, ranges: impl Into<ChunkRanges>) -> Self
pub fn root(self, ranges: impl Into<ChunkRanges>) -> Self
Specify ranges for the root blob (the HashSeq)
Sourcepub fn next(self, ranges: impl Into<ChunkRanges>) -> Self
pub fn next(self, ranges: impl Into<ChunkRanges>) -> Self
Specify ranges for the next offset.
Sourcepub fn build(self, hash: impl Into<Hash>) -> GetRequest
pub fn build(self, hash: impl Into<Hash>) -> GetRequest
Build a get request for the given hash, with the ranges specified in the builder.
Sourcepub fn build_open(self, hash: impl Into<Hash>) -> GetRequest
pub fn build_open(self, hash: impl Into<Hash>) -> GetRequest
Build a get request for the given hash, with the ranges specified in the builder and the last non-empty range repeating indefinitely.