pub struct EventSender { /* private fields */ }Implementations
Sourceimpl EventSender
Client for progress notifications.
impl EventSender
Client for progress notifications.
For most event types, the client can be configured to either send notifications or requests that can have a response.
pub fn new(client: Sender<ProviderMessage>, mask: EventMask) -> Self
pub fn channel( capacity: usize, mask: EventMask, ) -> (Self, Receiver<ProviderMessage>)
Sourcepub async fn client_connected(
&self,
f: impl Fn() -> ClientConnected,
) -> ClientResult
pub async fn client_connected( &self, f: impl Fn() -> ClientConnected, ) -> ClientResult
A new client has been connected.
Sourcepub async fn connection_closed(
&self,
f: impl Fn() -> ConnectionClosed,
) -> ClientResult
pub async fn connection_closed( &self, f: impl Fn() -> ConnectionClosed, ) -> ClientResult
A connection has been closed.