pub struct RequestReceived<R> {
pub connection_id: u64,
pub request_id: u64,
pub request: R,
}Expand description
A new get request was received from the provider.
Fields
connection_id: u64The connection id. Multiple requests can be sent over the same connection.
request_id: u64The request id. There is a new id for each request.
request: RThe request