pub struct TransferStats {
pub payload_bytes_sent: u64,
pub other_bytes_sent: u64,
pub other_bytes_read: u64,
pub duration: Duration,
}Expand description
Statistics about a successful or failed transfer.
Fields
payload_bytes_sent: u64The number of bytes sent that are part of the payload.
other_bytes_sent: u64The number of bytes sent that are not part of the payload.
Hash pairs and the initial size header.
other_bytes_read: u64The number of bytes read from the stream.
In most cases this is just the request, for push requests this is request, size header and hash pairs.
duration: DurationTotal duration from reading the request to transfer completed.