pub struct BaoFileStorageSubscriber { /* private fields */ }Implementations
Sourceimpl BaoFileStorageSubscriber
impl BaoFileStorageSubscriber
pub fn new(receiver: Receiver<BaoFileStorage>) -> Self
Sourcepub async fn forward(self, tx: Sender<Bitfield>) -> Result<()>
pub async fn forward(self, tx: Sender<Bitfield>) -> Result<()>
Forward observed values to the given sender
Returns an error if sending fails, or if the last sender is dropped
Sourcepub async fn forward_delta(self, tx: Sender<Bitfield>) -> Result<()>
pub async fn forward_delta(self, tx: Sender<Bitfield>) -> Result<()>
Forward observed deltas to the given sender
Returns an error if sending fails, or if the last sender is dropped