pub struct Hash(/* private fields */);Expand description
Hash type used throughout.
Implementations
Sourceimpl Hash
impl Hash
Sourcepub const fn from_bytes(bytes: [u8; 32]) -> Self
pub const fn from_bytes(bytes: [u8; 32]) -> Self
Create a Hash from its raw bytes representation.
Sourcepub fn fmt_short(&self) -> ArrayString<10>
pub fn fmt_short(&self) -> ArrayString<10>
Convert to a hex string limited to the first 5bytes for a friendly string representation of the hash.