Enum PoolConnectError
pub enum PoolConnectError {
Shutdown {
meta: Meta,
},
Timeout {
meta: Meta,
},
TooManyConnections {
meta: Meta,
},
ConnectError {
source: Arc<ConnectError>,
meta: Meta,
},
OnConnectError {
source: Arc<Error>,
meta: Meta,
},
}Expand description
Error when a connection can not be acquired
This includes the normal iroh connection errors as well as pool specific errors such as timeouts and connection limits.
Variants
Shutdown
Connection pool is shut down
Fields

meta: MetaCaptured call-site metadata
Timeout
Timeout during connect
Fields

meta: MetaCaptured call-site metadata
TooManyConnections
Too many connections
Fields

meta: MetaCaptured call-site metadata
ConnectError
Error during connect
OnConnectError
Error during on_connect callback