Struct ConnectionPool
pub struct ConnectionPool { /* private fields */ }Expand description
A connection pool
Implementations
impl ConnectionPool
impl ConnectionPool
pub fn new(endpoint: Endpoint, alpn: &[u8], options: Options) -> ConnectionPool
pub async fn get_or_connect(
&self,
id: PublicKey,
) -> Result<ConnectionRef, PoolConnectError>
pub async fn get_or_connect( &self, id: PublicKey, ) -> Result<ConnectionRef, PoolConnectError>
Returns either a fresh connection or a reference to an existing one.
This is guaranteed to return after approximately Options::connect_timeout with either an error or a connection.
pub async fn close(&self, id: PublicKey) -> Result<(), ConnectionPoolError>
pub async fn close(&self, id: PublicKey) -> Result<(), ConnectionPoolError>
Close an existing connection, if it exists
This will finish pending tasks and close the connection. New tasks will get a new connection if they are submitted after this call