Struct Options
pub struct Options {
pub idle_timeout: Duration,
pub connect_timeout: Duration,
pub max_connections: usize,
pub on_connected: Option<Arc<dyn Fn(&Endpoint, &Connection) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send>> + Sync + Send>>,
}Expand description
Configuration options for the connection pool
Fields
idle_timeout: DurationHow long to keep idle connections around.
connect_timeout: DurationTimeout for connect. This includes the time spent in on_connect, if set.
max_connections: usizeMaximum number of connections to hand out.
on_connected: Option<Arc<dyn Fn(&Endpoint, &Connection) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send>> + Sync + Send>>An optional callback that can be used to wait for the connection to enter some state. An example usage could be to wait for the connection to become direct before handing it out to the user.
Implementations